==> vmaid-1.8.20.tar.gz: vmaid-1.8.20/src/sigfile.h <==
/*
    Video maid
    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __SIGFILE_H__
#define __SIGFILE_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(タイマ)                                          *
*                                                                             *
******************************************************************************/
gboolean
signal_timeout (gpointer data);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(フレーム)                                        *
*                                                                             *
******************************************************************************/
gboolean
signal_focus_in (GtkWidget     *widget,
                 GdkEventFocus *event,
                 VmaidWindow   *vmaid);


gboolean
signal_focus_out (GtkWidget     *widget,
                  GdkEventFocus *event,
                  VmaidWindow   *vmaid);


void
signal_realize (GtkWidget *widget,
                gpointer   user_data);


void
signal_value_changed_hscroll (GtkAdjustment *adjust,
                              VmaidWindow   *vmaid);


gboolean
signal_config (GtkWidget         *widget,
               GdkEventConfigure *config,
               VmaidWindow       *vmaid);


void
signal_destroy_draw (GtkWidget   *widget,
                     VmaidWindow *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(描画)                                            *
*                                                                             *
******************************************************************************/
gboolean
signal_expose (GtkWidget      *widget,
               GdkEventExpose *event,
               VmaidWindow    *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(マウス)                                          *
*                                                                             *
******************************************************************************/
gboolean
signal_button_press_draw (GtkWidget      *widget,
                          GdkEventButton *event,
                          VmaidWindow    *vmaid);


gboolean
signal_motion_notify (GtkWidget      *widget,
                      GdkEventMotion *event,
                      VmaidWindow    *vmaid);


gboolean
signal_button_release (GtkWidget      *widget,
                       GdkEventButton *event,
                       VmaidWindow    *vmaid);


gboolean
signal_scroll (GtkWidget      *widget,
               GdkEventScroll *event,
               VmaidWindow    *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(キー)                                            *
*                                                                             *
******************************************************************************/
gboolean
signal_key_press (GtkWidget   *widget,
                  GdkEventKey *event,
                  VmaidWindow *vmaid);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif

==> vmaid-1.9.5.tar.gz: vmaid-1.9.5/src/sigfile.h <==
/*
    Video maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __SIGFILE_H__
#define __SIGFILE_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(タイマ)                                          *
*                                                                             *
******************************************************************************/
gboolean
signal_timeout (gpointer data);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(フレーム)                                        *
*                                                                             *
******************************************************************************/
gboolean
signal_focus_in (GtkWidget     *widget,
                 GdkEventFocus *event,
                 VmaidWindow   *vmaid);


gboolean
signal_focus_out (GtkWidget     *widget,
                  GdkEventFocus *event,
                  VmaidWindow   *vmaid);


void
signal_realize (GtkWidget *widget,
                gpointer   user_data);


void
signal_value_changed_hscroll (GtkAdjustment *adjust,
                              VmaidWindow   *vmaid);


gboolean
signal_config (GtkWidget         *widget,
               GdkEventConfigure *config,
               VmaidWindow       *vmaid);


void
signal_destroy_draw (GtkWidget   *widget,
                     VmaidWindow *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(描画)                                            *
*                                                                             *
******************************************************************************/
gboolean
signal_expose (GtkWidget      *widget,
               GdkEventExpose *event,
               VmaidWindow    *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(マウス)                                          *
*                                                                             *
******************************************************************************/
gboolean
signal_button_press_draw (GtkWidget      *widget,
                          GdkEventButton *event,
                          VmaidWindow    *vmaid);


gboolean
signal_motion_notify (GtkWidget      *widget,
                      GdkEventMotion *event,
                      VmaidWindow    *vmaid);


gboolean
signal_button_release (GtkWidget      *widget,
                       GdkEventButton *event,
                       VmaidWindow    *vmaid);


gboolean
signal_scroll (GtkWidget      *widget,
               GdkEventScroll *event,
               VmaidWindow    *vmaid);


/******************************************************************************
*                                                                             *
* ja:シグナル/イベント関数群(キー)                                            *
*                                                                             *
******************************************************************************/
gboolean
signal_key_press (GtkWidget   *widget,
                  GdkEventKey *event,
                  VmaidWindow *vmaid);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __SIGFILE_H__ */
